class MEM(object):
    """
    Base MEM class

    Workspace ONE UEM REST APIs enables you to manage emails on devices. 
    Through these APIs, you can retreive email management device details 
    and apply compliance policies to devices.
    """
    pass


# TODO: Implement